/*
 * Copyright (C) 2014, 2016 Karl Wette
 * Copyright (C) 2009-2013 Adam Mercer
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301 USA
 */

/*
 * LALPulsarVCSInfo.c - LALPulsar VCS Information
 */

#include <stdlib.h>
#include <config.h>

#include <lal/LALVCSInfoType.h>

#if defined(HAVE_LIBLAL)
#include <lal/LALVCSInfoHeader.h>
#endif
#if defined(HAVE_LIBLALFRAME)
#include <lal/LALFrameVCSInfoHeader.h>
#endif
#if defined(HAVE_LIBLALMETAIO)
#include <lal/LALMetaIOVCSInfoHeader.h>
#endif
#if defined(HAVE_LIBLALSIMULATION)
#include <lal/LALSimulationVCSInfoHeader.h>
#endif
#if defined(HAVE_LIBLALBURST)
#include <lal/LALBurstVCSInfoHeader.h>
#endif
#if defined(HAVE_LIBLALINSPIRAL)
#include <lal/LALInspiralVCSInfoHeader.h>
#endif
#if defined(HAVE_LIBLALINFERENCE)
#include <lal/LALInferenceVCSInfoHeader.h>
#endif
#if defined(HAVE_LIBLALPULSAR)
#include <lal/LALPulsarVCSInfoHeader.h>
#endif

#include "LALPulsarVCSInfoHeader.h"
#include "LALPulsarBuildInfoHeader.h"

/* VCS and build information */
const LALVCSInfo lalPulsarVCSInfo = {
  .name = "LALPulsar",
  .version = LALPULSAR_VERSION,
  .vcsId = LALPULSAR_VCS_ID,
  .vcsDate = LALPULSAR_VCS_DATE,
  .vcsBranch = LALPULSAR_VCS_BRANCH,
  .vcsTag = LALPULSAR_VCS_TAG,
  .vcsAuthor = LALPULSAR_VCS_AUTHOR,
  .vcsCommitter = LALPULSAR_VCS_COMMITTER,
  .vcsClean = LALPULSAR_VCS_CLEAN,
  .vcsStatus = LALPULSAR_VCS_STATUS,
  .configureArgs = LALPULSAR_CONFIGURE_ARGS,
  .configureDate = LALPULSAR_CONFIGURE_DATE,
  .buildDate = LALPULSAR_BUILD_DATE,
};

/* Identable VCS and build information */
const LALVCSInfo lalPulsarVCSIdentInfo = {
  .name = "$LALPulsarName: " "LALPulsar" " $",
  .version = "$LALPulsarVersion: " LALPULSAR_VERSION " $",
  .vcsId = "$LALPulsarVCSId: " LALPULSAR_VCS_ID " $",
  .vcsDate = "$LALPulsarVCSDate: " LALPULSAR_VCS_DATE " $",
  .vcsBranch = "$LALPulsarVCSBranch: " LALPULSAR_VCS_BRANCH " $",
  .vcsTag = "$LALPulsarVCSTag: " LALPULSAR_VCS_TAG " $",
  .vcsAuthor = "$LALPulsarVCSAuthor: " LALPULSAR_VCS_AUTHOR " $",
  .vcsCommitter = "$LALPulsarVCSCommitter: " LALPULSAR_VCS_COMMITTER " $",
  .vcsClean = "$LALPulsarVCSClean: " LALPULSAR_VCS_CLEAN " $",
  .vcsStatus = "$LALPulsarVCSStatus: " LALPULSAR_VCS_STATUS " $",
  .configureArgs = "$LALPulsarConfigureArgs: " LALPULSAR_CONFIGURE_ARGS " $",
  .configureDate = "$LALPulsarConfigureDate: " LALPULSAR_CONFIGURE_DATE " $",
  .buildDate = "$LALPulsarBuildDate: " LALPULSAR_BUILD_DATE " $",
};

/* NULL-terminated list of library and dependencies VCS and build information */
const LALVCSInfoList lalPulsarVCSInfoList = {
#if defined(HAVE_LIBLAL)
  &lalVCSInfo,
#endif
#if defined(HAVE_LIBLALFRAME)
  &lalFrameVCSInfo,
#endif
#if defined(HAVE_LIBLALMETAIO)
  &lalMetaIOVCSInfo,
#endif
#if defined(HAVE_LIBLALSIMULATION)
  &lalSimulationVCSInfo,
#endif
#if defined(HAVE_LIBLALBURST)
  &lalBurstVCSInfo,
#endif
#if defined(HAVE_LIBLALINSPIRAL)
  &lalInspiralVCSInfo,
#endif
#if defined(HAVE_LIBLALINFERENCE)
  &lalInferenceVCSInfo,
#endif
#if defined(HAVE_LIBLALPULSAR)
  &lalPulsarVCSInfo,
#endif
  &lalPulsarVCSInfo,
  NULL
};

#if LALPULSAR_VERSION_DEVEL != 0
/*
 * VCS header/library mismatch link check function:
 * This function will successfully link only if the link check functions defined
 * in the included LAL VCS info headers (e.g. LAL_VCS_LINK_CHECK() defined in
 * <lal/LALVCSInfoHeader.h>) are present in the LAL libraries being linked
 * against. A successful link ensures that the LAL headers included by this
 * library are consistent with the LAL libraries linked against by this library.
 */
void LALPULSAR_VCS_LINK_CHECK(void)
{
#if defined(HAVE_LIBLAL) && LAL_VERSION_DEVEL != 0
  LAL_VCS_LINK_CHECK();
#endif
#if defined(HAVE_LIBLALFRAME) && LALFRAME_VERSION_DEVEL != 0
  LALFRAME_VCS_LINK_CHECK();
#endif
#if defined(HAVE_LIBLALMETAIO) && LALMETAIO_VERSION_DEVEL != 0
  LALMETAIO_VCS_LINK_CHECK();
#endif
#if defined(HAVE_LIBLALSIMULATION) && LALSIMULATION_VERSION_DEVEL != 0
  LALSIMULATION_VCS_LINK_CHECK();
#endif
#if defined(HAVE_LIBLALBURST) && LALBURST_VERSION_DEVEL != 0
  LALBURST_VCS_LINK_CHECK();
#endif
#if defined(HAVE_LIBLALINSPIRAL) && LALINSPIRAL_VERSION_DEVEL != 0
  LALINSPIRAL_VCS_LINK_CHECK();
#endif
#if defined(HAVE_LIBLALINFERENCE) && LALINFERENCE_VERSION_DEVEL != 0
  LALINFERENCE_VCS_LINK_CHECK();
#endif
#if defined(HAVE_LIBLALPULSAR) && LALPULSAR_VERSION_DEVEL != 0
  LALPULSAR_VCS_LINK_CHECK();
#endif
}
#endif
